@@ -287,17 +287,17 @@ class diPWM:
         return threshold
 
 
-def create_diPwm(pathDiPwm):
-    """ Build list of lists from a file. One list per line.
+def create_diPwm(pathDiPwm, alphabet_choice = 'DNA'):
+    """ Build a diPWM object from a file.
 
     Args:
         pathDiPwm (string): path of the diPwm file
 
     Returns:
-        list of lists: list of lists with one list per line of the file.
+        diPWM object
     """    
-    #lecture de la matrice au format tabulé
+    #Read diPWM in a tabulated format
     with open(pathDiPwm) as file:
-        # User list comprehension to create a list of lists from the file
-        diPwm_matrix = diPWM([[float(y) for y in x.strip().split('\t')] for x in file.readlines() if x[0] != '>'])
+        # User list comprehension to create a diPWM object
+        diPwm_matrix = diPWM([[float(y) for y in x.strip().split('\t')] for x in file.readlines() if x[0] != '>'], alphabet_choice)
         return diPwm_matrix
